<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Activity Change Admin Tool
 *
 * @package    tool_actnotify
 * @copyright  2017  {@link http://bclearningnetwork.com}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */


// Standard GPL and phpdocs
require_once(__DIR__ . '/../../../config.php');
require_once($CFG->libdir.'/adminlib.php');
require_once('actnotify_form.php');
require_once(__DIR__.'/locallib.php');

// Calls require_login and performs permission checks for admin pages
admin_externalpage_setup('actnotify'); 

// Set up the page.
$title = get_string('pluginname', 'tool_actnotify');
$pagetitle = $title;
$url = new moodle_url("/admin/tool/actnotify/index.php");
$PAGE->set_url($url);
$PAGE->set_title($title);
$PAGE->set_heading($title); 
 
echo $OUTPUT->header();
echo $OUTPUT->heading(get_string('heading', 'tool_actnotify'));

$info = format_text(get_string('actchangeintro', 'tool_actnotify'), FORMAT_MARKDOWN);
echo $OUTPUT->box($info);

$success_output = $PAGE->get_renderer('tool_actnotify');

$mform = new actnotify_form();

if ($fromform = $mform->get_data()) {
	// process validated data
	// $mform->get_data() returns data posted in form
	$course = $fromform->course;
    $notify = $fromform->sendnotifications;

    tool_actnotify_set_notification(tool_actnotify_get_course_id($course), $notify);   
    
  	// Render success message HTML
	$renderable = new \tool_actnotify\output\success_html(get_string('notify', 'tool_actnotify'), tool_actnotify_get_course_string($course));
	echo $success_output->render($renderable);

	$mform->display();
} else {
	// this branch is executed if the form is submitted but the data doesn't validate and the form should be redisplayed
	// or on the first display of the form
	// display the form
	$mform->display();
}

 
echo $OUTPUT->footer();

?>